==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/AWSPlatformSpecFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class AWSPlatformSpecFluentImpl<A extends io.fabric8.openshift.api.model.AWSPlatformSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.AWSPlatformSpecFluent<A>{
  public AWSPlatformSpecFluentImpl() {
  }
  public AWSPlatformSpecFluentImpl(io.fabric8.openshift.api.model.AWSPlatformSpec instance) {
    this.withServiceEndpoints(instance.getServiceEndpoints()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<io.fabric8.openshift.api.model.AWSServiceEndpointBuilder> serviceEndpoints =  new java.util.ArrayList<io.fabric8.openshift.api.model.AWSServiceEndpointBuilder>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToServiceEndpoints(java.lang.Integer index,io.fabric8.openshift.api.model.AWSServiceEndpoint item) {
    if (this.serviceEndpoints == null) {this.serviceEndpoints = new java.util.ArrayList<io.fabric8.openshift.api.model.AWSServiceEndpointBuilder>();}
    io.fabric8.openshift.api.model.AWSServiceEndpointBuilder builder = new io.fabric8.openshift.api.model.AWSServiceEndpointBuilder(item);_visitables.get("serviceEndpoints").add(index >= 0 ? index : _visitables.get("serviceEndpoints").size(), builder);this.serviceEndpoints.add(index >= 0 ? index : serviceEndpoints.size(), builder); return (A)this;
  }
  public A setToServiceEndpoints(java.lang.Integer index,io.fabric8.openshift.api.model.AWSServiceEndpoint item) {
    if (this.serviceEndpoints == null) {this.serviceEndpoints = new java.util.ArrayList<io.fabric8.openshift.api.model.AWSServiceEndpointBuilder>();}
    io.fabric8.openshift.api.model.AWSServiceEndpointBuilder builder = new io.fabric8.openshift.api.model.AWSServiceEndpointBuilder(item);
    if (index < 0 || index >= _visitables.get("serviceEndpoints").size()) { _visitables.get("serviceEndpoints").add(builder); } else { _visitables.get("serviceEndpoints").set(index, builder);}
    if (index < 0 || index >= serviceEndpoints.size()) { serviceEndpoints.add(builder); } else { serviceEndpoints.set(index, builder);}
     return (A)this;
  }
  public A addToServiceEndpoints(io.fabric8.openshift.api.model.AWSServiceEndpoint... items) {
    if (this.serviceEndpoints == null) {this.serviceEndpoints = new java.util.ArrayList<io.fabric8.openshift.api.model.AWSServiceEndpointBuilder>();}
    for (io.fabric8.openshift.api.model.AWSServiceEndpoint item : items) {io.fabric8.openshift.api.model.AWSServiceEndpointBuilder builder = new io.fabric8.openshift.api.model.AWSServiceEndpointBuilder(item);_visitables.get("serviceEndpoints").add(builder);this.serviceEndpoints.add(builder);} return (A)this;
  }
  public A addAllToServiceEndpoints(java.util.Collection<io.fabric8.openshift.api.model.AWSServiceEndpoint> items) {
    if (this.serviceEndpoints == null) {this.serviceEndpoints = new java.util.ArrayList<io.fabric8.openshift.api.model.AWSServiceEndpointBuilder>();}
    for (io.fabric8.openshift.api.model.AWSServiceEndpoint item : items) {io.fabric8.openshift.api.model.AWSServiceEndpointBuilder builder = new io.fabric8.openshift.api.model.AWSServiceEndpointBuilder(item);_visitables.get("serviceEndpoints").add(builder);this.serviceEndpoints.add(builder);} return (A)this;
  }
  public A removeFromServiceEndpoints(io.fabric8.openshift.api.model.AWSServiceEndpoint... items) {
    for (io.fabric8.openshift.api.model.AWSServiceEndpoint item : items) {io.fabric8.openshift.api.model.AWSServiceEndpointBuilder builder = new io.fabric8.openshift.api.model.AWSServiceEndpointBuilder(item);_visitables.get("serviceEndpoints").remove(builder);if (this.serviceEndpoints != null) {this.serviceEndpoints.remove(builder);}} return (A)this;
  }
  public A removeAllFromServiceEndpoints(java.util.Collection<io.fabric8.openshift.api.model.AWSServiceEndpoint> items) {
    for (io.fabric8.openshift.api.model.AWSServiceEndpoint item : items) {io.fabric8.openshift.api.model.AWSServiceEndpointBuilder builder = new io.fabric8.openshift.api.model.AWSServiceEndpointBuilder(item);_visitables.get("serviceEndpoints").remove(builder);if (this.serviceEndpoints != null) {this.serviceEndpoints.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromServiceEndpoints(java.util.function.Predicate<io.fabric8.openshift.api.model.AWSServiceEndpointBuilder> predicate) {
    if (serviceEndpoints == null) return (A) this;
    final Iterator<io.fabric8.openshift.api.model.AWSServiceEndpointBuilder> each = serviceEndpoints.iterator();
    final List visitables = _visitables.get("serviceEndpoints");
    while (each.hasNext()) {
      io.fabric8.openshift.api.model.AWSServiceEndpointBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildServiceEndpoints instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.AWSServiceEndpoint> getServiceEndpoints() {
    return build(serviceEndpoints);
  }
  public java.util.List<io.fabric8.openshift.api.model.AWSServiceEndpoint> buildServiceEndpoints() {
    return build(serviceEndpoints);
  }
  public io.fabric8.openshift.api.model.AWSServiceEndpoint buildServiceEndpoint(java.lang.Integer index) {
    return this.serviceEndpoints.get(index).build();
  }
  public io.fabric8.openshift.api.model.AWSServiceEndpoint buildFirstServiceEndpoint() {
    return this.serviceEndpoints.get(0).build();
  }
  public io.fabric8.openshift.api.model.AWSServiceEndpoint buildLastServiceEndpoint() {
    return this.serviceEndpoints.get(serviceEndpoints.size() - 1).build();
  }
  public io.fabric8.openshift.api.model.AWSServiceEndpoint buildMatchingServiceEndpoint(java.util.function.Predicate<io.fabric8.openshift.api.model.AWSServiceEndpointBuilder> predicate) {
    for (io.fabric8.openshift.api.model.AWSServiceEndpointBuilder item: serviceEndpoints) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingServiceEndpoint(java.util.function.Predicate<io.fabric8.openshift.api.model.AWSServiceEndpointBuilder> predicate) {
    for (io.fabric8.openshift.api.model.AWSServiceEndpointBuilder item: serviceEndpoints) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withServiceEndpoints(java.util.List<io.fabric8.openshift.api.model.AWSServiceEndpoint> serviceEndpoints) {
    if (this.serviceEndpoints != null) { _visitables.get("serviceEndpoints").removeAll(this.serviceEndpoints);}
    if (serviceEndpoints != null) {this.serviceEndpoints = new java.util.ArrayList<io.fabric8.openshift.api.model.AWSServiceEndpointBuilder>(); for (io.fabric8.openshift.api.model.AWSServiceEndpoint item : serviceEndpoints){this.addToServiceEndpoints(item);}} else { this.serviceEndpoints = null;} return (A) this;
  }
  public A withServiceEndpoints(io.fabric8.openshift.api.model.AWSServiceEndpoint... serviceEndpoints) {
    if (this.serviceEndpoints != null) {this.serviceEndpoints.clear();}
    if (serviceEndpoints != null) {for (io.fabric8.openshift.api.model.AWSServiceEndpoint item :serviceEndpoints){ this.addToServiceEndpoints(item);}} return (A) this;
  }
  public java.lang.Boolean hasServiceEndpoints() {
    return serviceEndpoints != null && !serviceEndpoints.isEmpty();
  }
  public A addNewServiceEndpoint(java.lang.String name,java.lang.String url) {
    return (A)addToServiceEndpoints(new AWSServiceEndpoint(name, url));
  }
  public io.fabric8.openshift.api.model.AWSPlatformSpecFluent.ServiceEndpointsNested<A> addNewServiceEndpoint() {
    return new io.fabric8.openshift.api.model.AWSPlatformSpecFluentImpl.ServiceEndpointsNestedImpl();
  }
  public io.fabric8.openshift.api.model.AWSPlatformSpecFluent.ServiceEndpointsNested<A> addNewServiceEndpointLike(io.fabric8.openshift.api.model.AWSServiceEndpoint item) {
    return new io.fabric8.openshift.api.model.AWSPlatformSpecFluentImpl.ServiceEndpointsNestedImpl(-1, item);
  }
  public io.fabric8.openshift.api.model.AWSPlatformSpecFluent.ServiceEndpointsNested<A> setNewServiceEndpointLike(java.lang.Integer index,io.fabric8.openshift.api.model.AWSServiceEndpoint item) {
    return new io.fabric8.openshift.api.model.AWSPlatformSpecFluentImpl.ServiceEndpointsNestedImpl(index, item);
  }
  public io.fabric8.openshift.api.model.AWSPlatformSpecFluent.ServiceEndpointsNested<A> editServiceEndpoint(java.lang.Integer index) {
    if (serviceEndpoints.size() <= index) throw new RuntimeException("Can't edit serviceEndpoints. Index exceeds size.");
    return setNewServiceEndpointLike(index, buildServiceEndpoint(index));
  }
  public io.fabric8.openshift.api.model.AWSPlatformSpecFluent.ServiceEndpointsNested<A> editFirstServiceEndpoint() {
    if (serviceEndpoints.size() == 0) throw new RuntimeException("Can't edit first serviceEndpoints. The list is empty.");
    return setNewServiceEndpointLike(0, buildServiceEndpoint(0));
  }
  public io.fabric8.openshift.api.model.AWSPlatformSpecFluent.ServiceEndpointsNested<A> editLastServiceEndpoint() {
    int index = serviceEndpoints.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last serviceEndpoints. The list is empty.");
    return setNewServiceEndpointLike(index, buildServiceEndpoint(index));
  }
  public io.fabric8.openshift.api.model.AWSPlatformSpecFluent.ServiceEndpointsNested<A> editMatchingServiceEndpoint(java.util.function.Predicate<io.fabric8.openshift.api.model.AWSServiceEndpointBuilder> predicate) {
    int index = -1;
    for (int i=0;i<serviceEndpoints.size();i++) { 
    if (predicate.test(serviceEndpoints.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching serviceEndpoints. No match found.");
    return setNewServiceEndpointLike(index, buildServiceEndpoint(index));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    AWSPlatformSpecFluentImpl that = (AWSPlatformSpecFluentImpl) o;
    if (serviceEndpoints != null ? !serviceEndpoints.equals(that.serviceEndpoints) :that.serviceEndpoints != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(serviceEndpoints,  additionalProperties,  super.hashCode());
  }
  public class ServiceEndpointsNestedImpl<N> extends io.fabric8.openshift.api.model.AWSServiceEndpointFluentImpl<io.fabric8.openshift.api.model.AWSPlatformSpecFluent.ServiceEndpointsNested<N>> implements io.fabric8.openshift.api.model.AWSPlatformSpecFluent.ServiceEndpointsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ServiceEndpointsNestedImpl(java.lang.Integer index,io.fabric8.openshift.api.model.AWSServiceEndpoint item) {
      this.index = index;
      this.builder = new io.fabric8.openshift.api.model.AWSServiceEndpointBuilder(this, item);
    }
    ServiceEndpointsNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.openshift.api.model.AWSServiceEndpointBuilder(this);
    }
    io.fabric8.openshift.api.model.AWSServiceEndpointBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) AWSPlatformSpecFluentImpl.this.setToServiceEndpoints(index,builder.build());
    }
    public N endServiceEndpoint() {
      return and();
    }
    
  }
  
}

==> openshift-model-5.12.1-sources.jar: io/fabric8/openshift/api/model/AWSPlatformSpecFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class AWSPlatformSpecFluentImpl<A extends io.fabric8.openshift.api.model.AWSPlatformSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.AWSPlatformSpecFluent<A>{
  public AWSPlatformSpecFluentImpl() {
  }
  public AWSPlatformSpecFluentImpl(io.fabric8.openshift.api.model.AWSPlatformSpec instance) {
    this.withServiceEndpoints(instance.getServiceEndpoints()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<io.fabric8.openshift.api.model.AWSServiceEndpointBuilder> serviceEndpoints =  new java.util.ArrayList<io.fabric8.openshift.api.model.AWSServiceEndpointBuilder>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToServiceEndpoints(java.lang.Integer index,io.fabric8.openshift.api.model.AWSServiceEndpoint item) {
    if (this.serviceEndpoints == null) {this.serviceEndpoints = new java.util.ArrayList<io.fabric8.openshift.api.model.AWSServiceEndpointBuilder>();}
    io.fabric8.openshift.api.model.AWSServiceEndpointBuilder builder = new io.fabric8.openshift.api.model.AWSServiceEndpointBuilder(item);_visitables.get("serviceEndpoints").add(index >= 0 ? index : _visitables.get("serviceEndpoints").size(), builder);this.serviceEndpoints.add(index >= 0 ? index : serviceEndpoints.size(), builder); return (A)this;
  }
  public A setToServiceEndpoints(java.lang.Integer index,io.fabric8.openshift.api.model.AWSServiceEndpoint item) {
    if (this.serviceEndpoints == null) {this.serviceEndpoints = new java.util.ArrayList<io.fabric8.openshift.api.model.AWSServiceEndpointBuilder>();}
    io.fabric8.openshift.api.model.AWSServiceEndpointBuilder builder = new io.fabric8.openshift.api.model.AWSServiceEndpointBuilder(item);
    if (index < 0 || index >= _visitables.get("serviceEndpoints").size()) { _visitables.get("serviceEndpoints").add(builder); } else { _visitables.get("serviceEndpoints").set(index, builder);}
    if (index < 0 || index >= serviceEndpoints.size()) { serviceEndpoints.add(builder); } else { serviceEndpoints.set(index, builder);}
     return (A)this;
  }
  public A addToServiceEndpoints(io.fabric8.openshift.api.model.AWSServiceEndpoint... items) {
    if (this.serviceEndpoints == null) {this.serviceEndpoints = new java.util.ArrayList<io.fabric8.openshift.api.model.AWSServiceEndpointBuilder>();}
    for (io.fabric8.openshift.api.model.AWSServiceEndpoint item : items) {io.fabric8.openshift.api.model.AWSServiceEndpointBuilder builder = new io.fabric8.openshift.api.model.AWSServiceEndpointBuilder(item);_visitables.get("serviceEndpoints").add(builder);this.serviceEndpoints.add(builder);} return (A)this;
  }
  public A addAllToServiceEndpoints(java.util.Collection<io.fabric8.openshift.api.model.AWSServiceEndpoint> items) {
    if (this.serviceEndpoints == null) {this.serviceEndpoints = new java.util.ArrayList<io.fabric8.openshift.api.model.AWSServiceEndpointBuilder>();}
    for (io.fabric8.openshift.api.model.AWSServiceEndpoint item : items) {io.fabric8.openshift.api.model.AWSServiceEndpointBuilder builder = new io.fabric8.openshift.api.model.AWSServiceEndpointBuilder(item);_visitables.get("serviceEndpoints").add(builder);this.serviceEndpoints.add(builder);} return (A)this;
  }
  public A removeFromServiceEndpoints(io.fabric8.openshift.api.model.AWSServiceEndpoint... items) {
    for (io.fabric8.openshift.api.model.AWSServiceEndpoint item : items) {io.fabric8.openshift.api.model.AWSServiceEndpointBuilder builder = new io.fabric8.openshift.api.model.AWSServiceEndpointBuilder(item);_visitables.get("serviceEndpoints").remove(builder);if (this.serviceEndpoints != null) {this.serviceEndpoints.remove(builder);}} return (A)this;
  }
  public A removeAllFromServiceEndpoints(java.util.Collection<io.fabric8.openshift.api.model.AWSServiceEndpoint> items) {
    for (io.fabric8.openshift.api.model.AWSServiceEndpoint item : items) {io.fabric8.openshift.api.model.AWSServiceEndpointBuilder builder = new io.fabric8.openshift.api.model.AWSServiceEndpointBuilder(item);_visitables.get("serviceEndpoints").remove(builder);if (this.serviceEndpoints != null) {this.serviceEndpoints.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromServiceEndpoints(java.util.function.Predicate<io.fabric8.openshift.api.model.AWSServiceEndpointBuilder> predicate) {
    if (serviceEndpoints == null) return (A) this;
    final Iterator<io.fabric8.openshift.api.model.AWSServiceEndpointBuilder> each = serviceEndpoints.iterator();
    final List visitables = _visitables.get("serviceEndpoints");
    while (each.hasNext()) {
      io.fabric8.openshift.api.model.AWSServiceEndpointBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildServiceEndpoints instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.AWSServiceEndpoint> getServiceEndpoints() {
    return build(serviceEndpoints);
  }
  public java.util.List<io.fabric8.openshift.api.model.AWSServiceEndpoint> buildServiceEndpoints() {
    return build(serviceEndpoints);
  }
  public io.fabric8.openshift.api.model.AWSServiceEndpoint buildServiceEndpoint(java.lang.Integer index) {
    return this.serviceEndpoints.get(index).build();
  }
  public io.fabric8.openshift.api.model.AWSServiceEndpoint buildFirstServiceEndpoint() {
    return this.serviceEndpoints.get(0).build();
  }
  public io.fabric8.openshift.api.model.AWSServiceEndpoint buildLastServiceEndpoint() {
    return this.serviceEndpoints.get(serviceEndpoints.size() - 1).build();
  }
  public io.fabric8.openshift.api.model.AWSServiceEndpoint buildMatchingServiceEndpoint(java.util.function.Predicate<io.fabric8.openshift.api.model.AWSServiceEndpointBuilder> predicate) {
    for (io.fabric8.openshift.api.model.AWSServiceEndpointBuilder item: serviceEndpoints) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingServiceEndpoint(java.util.function.Predicate<io.fabric8.openshift.api.model.AWSServiceEndpointBuilder> predicate) {
    for (io.fabric8.openshift.api.model.AWSServiceEndpointBuilder item: serviceEndpoints) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withServiceEndpoints(java.util.List<io.fabric8.openshift.api.model.AWSServiceEndpoint> serviceEndpoints) {
    if (this.serviceEndpoints != null) { _visitables.get("serviceEndpoints").removeAll(this.serviceEndpoints);}
    if (serviceEndpoints != null) {this.serviceEndpoints = new java.util.ArrayList(); for (io.fabric8.openshift.api.model.AWSServiceEndpoint item : serviceEndpoints){this.addToServiceEndpoints(item);}} else { this.serviceEndpoints = null;} return (A) this;
  }
  public A withServiceEndpoints(io.fabric8.openshift.api.model.AWSServiceEndpoint... serviceEndpoints) {
    if (this.serviceEndpoints != null) {this.serviceEndpoints.clear();}
    if (serviceEndpoints != null) {for (io.fabric8.openshift.api.model.AWSServiceEndpoint item :serviceEndpoints){ this.addToServiceEndpoints(item);}} return (A) this;
  }
  public java.lang.Boolean hasServiceEndpoints() {
    return serviceEndpoints != null && !serviceEndpoints.isEmpty();
  }
  public A addNewServiceEndpoint(java.lang.String name,java.lang.String url) {
    return (A)addToServiceEndpoints(new AWSServiceEndpoint(name, url));
  }
  public io.fabric8.openshift.api.model.AWSPlatformSpecFluent.ServiceEndpointsNested<A> addNewServiceEndpoint() {
    return new io.fabric8.openshift.api.model.AWSPlatformSpecFluentImpl.ServiceEndpointsNestedImpl();
  }
  public io.fabric8.openshift.api.model.AWSPlatformSpecFluent.ServiceEndpointsNested<A> addNewServiceEndpointLike(io.fabric8.openshift.api.model.AWSServiceEndpoint item) {
    return new io.fabric8.openshift.api.model.AWSPlatformSpecFluentImpl.ServiceEndpointsNestedImpl(-1, item);
  }
  public io.fabric8.openshift.api.model.AWSPlatformSpecFluent.ServiceEndpointsNested<A> setNewServiceEndpointLike(java.lang.Integer index,io.fabric8.openshift.api.model.AWSServiceEndpoint item) {
    return new io.fabric8.openshift.api.model.AWSPlatformSpecFluentImpl.ServiceEndpointsNestedImpl(index, item);
  }
  public io.fabric8.openshift.api.model.AWSPlatformSpecFluent.ServiceEndpointsNested<A> editServiceEndpoint(java.lang.Integer index) {
    if (serviceEndpoints.size() <= index) throw new RuntimeException("Can't edit serviceEndpoints. Index exceeds size.");
    return setNewServiceEndpointLike(index, buildServiceEndpoint(index));
  }
  public io.fabric8.openshift.api.model.AWSPlatformSpecFluent.ServiceEndpointsNested<A> editFirstServiceEndpoint() {
    if (serviceEndpoints.size() == 0) throw new RuntimeException("Can't edit first serviceEndpoints. The list is empty.");
    return setNewServiceEndpointLike(0, buildServiceEndpoint(0));
  }
  public io.fabric8.openshift.api.model.AWSPlatformSpecFluent.ServiceEndpointsNested<A> editLastServiceEndpoint() {
    int index = serviceEndpoints.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last serviceEndpoints. The list is empty.");
    return setNewServiceEndpointLike(index, buildServiceEndpoint(index));
  }
  public io.fabric8.openshift.api.model.AWSPlatformSpecFluent.ServiceEndpointsNested<A> editMatchingServiceEndpoint(java.util.function.Predicate<io.fabric8.openshift.api.model.AWSServiceEndpointBuilder> predicate) {
    int index = -1;
    for (int i=0;i<serviceEndpoints.size();i++) { 
    if (predicate.test(serviceEndpoints.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching serviceEndpoints. No match found.");
    return setNewServiceEndpointLike(index, buildServiceEndpoint(index));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    AWSPlatformSpecFluentImpl that = (AWSPlatformSpecFluentImpl) o;
    if (serviceEndpoints != null ? !serviceEndpoints.equals(that.serviceEndpoints) :that.serviceEndpoints != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(serviceEndpoints,  additionalProperties,  super.hashCode());
  }
  public class ServiceEndpointsNestedImpl<N> extends io.fabric8.openshift.api.model.AWSServiceEndpointFluentImpl<io.fabric8.openshift.api.model.AWSPlatformSpecFluent.ServiceEndpointsNested<N>> implements io.fabric8.openshift.api.model.AWSPlatformSpecFluent.ServiceEndpointsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ServiceEndpointsNestedImpl(java.lang.Integer index,io.fabric8.openshift.api.model.AWSServiceEndpoint item) {
      this.index = index;
      this.builder = new io.fabric8.openshift.api.model.AWSServiceEndpointBuilder(this, item);
    }
    ServiceEndpointsNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.openshift.api.model.AWSServiceEndpointBuilder(this);
    }
    io.fabric8.openshift.api.model.AWSServiceEndpointBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) AWSPlatformSpecFluentImpl.this.setToServiceEndpoints(index,builder.build());
    }
    public N endServiceEndpoint() {
      return and();
    }
    
  }
  
}
